# Generated by roxygen2: do not edit by hand

S3method(as.rpart,e2tree)
S3method(e2splits,e2tree)
S3method(extract_terminal_nodes,catboost.CatBoost)
S3method(extract_terminal_nodes,catboost.Model)
S3method(extract_terminal_nodes,default)
S3method(extract_terminal_nodes,gbm)
S3method(extract_terminal_nodes,lgb.Booster)
S3method(extract_terminal_nodes,randomForest)
S3method(extract_terminal_nodes,ranger)
S3method(extract_terminal_nodes,xgb.Booster)
S3method(fitted,e2tree)
S3method(get_ensemble_predictions,catboost.CatBoost)
S3method(get_ensemble_predictions,catboost.Model)
S3method(get_ensemble_predictions,default)
S3method(get_ensemble_predictions,gbm)
S3method(get_ensemble_predictions,lgb.Booster)
S3method(get_ensemble_predictions,randomForest)
S3method(get_ensemble_predictions,ranger)
S3method(get_ensemble_predictions,xgb.Booster)
S3method(get_ensemble_type,catboost.CatBoost)
S3method(get_ensemble_type,catboost.Model)
S3method(get_ensemble_type,default)
S3method(get_ensemble_type,gbm)
S3method(get_ensemble_type,lgb.Booster)
S3method(get_ensemble_type,randomForest)
S3method(get_ensemble_type,ranger)
S3method(get_ensemble_type,xgb.Booster)
S3method(measures,eValidation)
S3method(nodes,e2tree)
S3method(plot,e2tree)
S3method(plot,eValidation)
S3method(plot,loi)
S3method(plot,loi_perm)
S3method(predict,e2tree)
S3method(print,e2tree)
S3method(print,eValidation)
S3method(print,loi)
S3method(print,loi_perm)
S3method(proximity,eValidation)
S3method(residuals,e2tree)
S3method(summary,e2tree)
S3method(summary,eValidation)
S3method(summary,loi)
S3method(summary,loi_perm)
export(as.rpart)
export(createDisMatrix)
export(e2splits)
export(e2tree)
export(ePredTree)
export(eValidation)
export(extract_terminal_nodes)
export(get_ensemble_predictions)
export(get_ensemble_type)
export(loi)
export(loi_perm)
export(measures)
export(nodes)
export(plot_e2tree)
export(plot_e2tree_click)
export(plot_e2tree_vis)
export(print_e2tree_summary)
export(proximity)
export(roc)
export(rpart2Tree)
export(save_e2tree_html)
export(vimp)
import(future.apply)
import(ggplot2)
import(parallel)
import(partitions)
import(purrr)
import(rpart.plot)
import(stats)
importFrom(Matrix,"%&%")
importFrom(Matrix,Matrix)
importFrom(Matrix,all.equal)
importFrom(Matrix,as.array)
importFrom(Matrix,as.matrix)
importFrom(Matrix,rowSums)
importFrom(Matrix,sparseMatrix)
importFrom(Rcpp,evalCpp)
importFrom(Rcpp,sourceCpp)
importFrom(dplyr,"%>%")
importFrom(dplyr,across)
importFrom(dplyr,arrange)
importFrom(dplyr,as_tibble)
importFrom(dplyr,count)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,do)
importFrom(dplyr,first)
importFrom(dplyr,group_by)
importFrom(dplyr,group_by_at)
importFrom(dplyr,if_else)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_if)
importFrom(dplyr,n)
importFrom(dplyr,pick)
importFrom(dplyr,relocate)
importFrom(dplyr,rename)
importFrom(dplyr,rename_with)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,slice_head)
importFrom(dplyr,slice_tail)
importFrom(dplyr,starts_with)
importFrom(dplyr,summarize)
importFrom(dplyr,tibble)
importFrom(dplyr,top_n)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.cur)
importFrom(grDevices,dev.new)
importFrom(grDevices,devAskNewPage)
importFrom(grDevices,rainbow)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,box)
importFrom(graphics,hist)
importFrom(graphics,image)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,locator)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(tidyr,complete)
importFrom(tidyr,drop_na)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,replace_na)
importFrom(utils,globalVariables)
importFrom(utils,head)
importFrom(utils,setTxtProgressBar)
importFrom(utils,tail)
importFrom(utils,txtProgressBar)
useDynLib(e2tree)
