# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

compute_impurity_cpp <- function(y, S) {
    .Call('_e2tree_compute_impurity_cpp', PACKAGE = 'e2tree', y, S)
}

compute_cooccurrences_sparse_cpp <- function(type, obs, tree_index, n_total, maxvar = NA_real_) {
    .Call('_e2tree_compute_cooccurrences_sparse_cpp', PACKAGE = 'e2tree', type, obs, tree_index, n_total, maxvar)
}

compute_cooccurrences_cpp <- function(type, obs, w, tree_index, maxvar = NA_real_) {
    .Call('_e2tree_compute_cooccurrences_cpp', PACKAGE = 'e2tree', type, obs, w, tree_index, maxvar)
}

compute_all_cooccurrences_cpp <- function(type, obs, ntree, n_cores, maxvar = NA_real_) {
    .Call('_e2tree_compute_all_cooccurrences_cpp', PACKAGE = 'e2tree', type, obs, ntree, n_cores, maxvar)
}

compute_dissimilarity_from_cooc_cpp <- function(a) {
    .Call('_e2tree_compute_dissimilarity_from_cooc_cpp', PACKAGE = 'e2tree', a)
}

