% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/aaa_utils.R
\name{check_package}
\alias{check_package}
\title{Check Availability of Suggested Packages}
\usage{
check_package(pkg)
}
\description{
Check Availability of Suggested Packages
}
\keyword{internal}
