% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/aaa_utils.R
\name{e2_variance}
\alias{e2_variance}
\title{Population Variance}
\usage{
e2_variance(x)
}
\description{
Population Variance
}
\keyword{internal}
