% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_e2tree_click.R
\name{print_e2tree_summary}
\alias{print_e2tree_summary}
\title{Print E2Tree Summary}
\usage{
print_e2tree_summary(fit, data)
}
\arguments{
\item{fit}{An e2tree object}

\item{data}{The training data}
}
\description{
Prints a comprehensive summary of an E2Tree model including
all decision rules, variable importance, and node statistics.
}
